@@ -1,15 +1,13 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2015-2022 CERN.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """UI for Invenio-Search."""
 
-from __future__ import absolute_import, print_function
-
 from . import config
 from .views import blueprint
 
@@ -31,7 +29,6 @@ class InvenioSearchUI(object):
         :param app: The Flask application.
         """
         self.init_config(app)
-        app.register_blueprint(blueprint)
         app.extensions['invenio-search-ui'] = self
 
     def init_config(self, app):
